Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-6]: src/external/ibm-public/postfix/dist external/ibm-public/post...



details:   https://anonhg.NetBSD.org/src/rev/a4ceb121e0a6
branches:  netbsd-6
changeset: 776429:a4ceb121e0a6
user:      bouyer <bouyer%NetBSD.org@localhost>
date:      Sat Sep 07 16:28:34 2013 +0000

description:
external/ibm-public/postfix/dist/HISTORY                        patch
external/ibm-public/postfix/dist/src/global/mail_version.h      patch
external/ibm-public/postfix/dist/src/smtp/smtp_connect.c        patch
external/ibm-public/postfix/dist/src/smtp/smtp_reuse.c          patch
external/ibm-public/postfix/dist/src/tls/tls_misc.c             patch
external/ibm-public/postfix/dist/src/trivial-rewrite/resolve.c  patch
external/ibm-public/postfix/dist/src/util/exec_command.c        patch

        Update postfix to 2.8.15, fixing several bugs
        [tron, ticket #938]

diffstat:

 external/ibm-public/postfix/dist/HISTORY                       |  39 ++++++++++
 external/ibm-public/postfix/dist/src/global/mail_version.h     |   6 +-
 external/ibm-public/postfix/dist/src/smtp/smtp_connect.c       |   6 +-
 external/ibm-public/postfix/dist/src/smtp/smtp_reuse.c         |   4 +-
 external/ibm-public/postfix/dist/src/tls/tls_misc.c            |   6 +-
 external/ibm-public/postfix/dist/src/trivial-rewrite/resolve.c |  15 +++-
 external/ibm-public/postfix/dist/src/util/exec_command.c       |   5 +-
 7 files changed, 66 insertions(+), 15 deletions(-)

diffs (178 lines):

diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/HISTORY
--- a/external/ibm-public/postfix/dist/HISTORY  Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/HISTORY  Sat Sep 07 16:28:34 2013 +0000
@@ -16876,3 +16876,42 @@
        20101108 change that removes datalink suffixes in the SMTP
        and QMQP servers, but we leave that code alone.  File:
        util/myaddrinfo.c.
+
+20130131
+
+       Bugfix: the local(8) delivery agent dereferenced a null
+       pointer while delivering to null command (for example, "|"
+       in a .forward file).  Reported by Gilles Chehade.
+
+20130203
+
+       Bugfix: the 20121010 fix for tls_misc.c was documented but
+       not included.
+
+20130403
+
+       Bugfix (introduced: Postfix 2.3): don't reuse TCP connections
+       when smtp_tls_policy_maps is specified. Victor Duchovni.
+       Found during Postfix 2.11 code maintenance.  File:
+       smtp/smtp_reuse.c.
+
+20130423
+
+       Bugfix (introduced: Postfix 2.0): when myhostname is not
+       listed in mydestination, the trivial-rewrite resolver may
+       log "do not list <myhostname value> in both mydestination
+       and <name of non-mydestination domain list>".  The fix is
+       to re-resolve a domain-less address after adding $myhostname
+       as the surrogate domain, so that it pops out with the right
+       address-class label.  Problem reported by Quanah Gibson-Mount.
+       File: trivial-rewrite/resolve.c.
+
+20130425
+
+       Bugfix (introduced: Postfix 2.2): don't reuse TCP connections
+       when SASL authentication is enabled. SASL passwords may
+       depend on the remote SMTP server hostname, but the Postfix
+       <2.11 SMTP connection cache client does not distinguish
+       between different hostnames that resolve to the same IP
+       address.  Found during Postfix 2.11 code maintenance.  File:
+       smtp/smtp_connect.c.
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/global/mail_version.h
--- a/external/ibm-public/postfix/dist/src/global/mail_version.h        Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/global/mail_version.h        Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mail_version.h,v 1.1.1.12.2.4 2013/01/07 15:41:56 riz Exp $    */
+/*     $NetBSD: mail_version.h,v 1.1.1.12.2.5 2013/09/07 16:28:34 bouyer Exp $ */
 
 #ifndef _MAIL_VERSION_H_INCLUDED_
 #define _MAIL_VERSION_H_INCLUDED_
@@ -22,8 +22,8 @@
   * Patches change both the patchlevel and the release date. Snapshots have no
   * patchlevel; they change the release date only.
   */
-#define MAIL_RELEASE_DATE      "20121213"
-#define MAIL_VERSION_NUMBER    "2.8.13"
+#define MAIL_RELEASE_DATE      "20130622"
+#define MAIL_VERSION_NUMBER    "2.8.15"
 
 #ifdef SNAPSHOT
 # define MAIL_VERSION_DATE     "-" MAIL_RELEASE_DATE
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/smtp/smtp_reuse.c
--- a/external/ibm-public/postfix/dist/src/smtp/smtp_reuse.c    Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/smtp/smtp_reuse.c    Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: smtp_reuse.c,v 1.1.1.1 2009/06/23 10:08:54 tron Exp $  */
+/*     $NetBSD: smtp_reuse.c,v 1.1.1.1.12.1 2013/09/07 16:28:34 bouyer Exp $   */
 
 /*++
 /* NAME
@@ -272,7 +272,7 @@
      * credentials or the wrong TLS policy.
      */
     if ((var_smtp_tls_per_site && *var_smtp_tls_per_site)
-       || (var_smtp_sasl_passwd && *var_smtp_sasl_passwd))
+       || (var_smtp_tls_policy && *var_smtp_tls_policy))
        return (0);
 
     /*
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/tls/tls_misc.c
--- a/external/ibm-public/postfix/dist/src/tls/tls_misc.c       Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/tls/tls_misc.c       Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: tls_misc.c,v 1.1.1.3.6.1 2012/06/13 19:29:04 riz Exp $ */
+/*     $NetBSD: tls_misc.c,v 1.1.1.3.6.2 2013/09/07 16:28:34 bouyer Exp $      */
 
 /*++
 /* NAME
@@ -455,8 +455,10 @@
        else
            include |= code =
                name_code(protocol_table, NAME_CODE_FLAG_NONE, tok);
-       if (code == TLS_PROTOCOL_INVALID)
+       if (code == TLS_PROTOCOL_INVALID) {
+           myfree(save);
            return TLS_PROTOCOL_INVALID;
+       }
     }
     myfree(save);
 
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/trivial-rewrite/resolve.c
--- a/external/ibm-public/postfix/dist/src/trivial-rewrite/resolve.c    Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/trivial-rewrite/resolve.c    Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: resolve.c,v 1.1.1.3 2010/06/17 18:07:10 tron Exp $     */
+/*     $NetBSD: resolve.c,v 1.1.1.3.8.1 2013/09/07 16:28:34 bouyer Exp $       */
 
 /*++
 /* NAME
@@ -326,9 +326,18 @@
            tok822_free(tree->head);
            tree->head = 0;
        }
-       /* XXX must be localpart only, not user@domain form. */
-       if (tree->head == 0)
+       /* XXX Re-resolve the surrogate, in case already in user@domain form. */
+       if (tree->head == 0) {
            tree->head = tok822_scan(var_empty_addr, &tree->tail);
+           continue;
+       }
+
+       /* XXX Re-resolve with @$myhostname for backwards compatibility. */
+       if (domain == 0 && saved_domain == 0) {
+           tok822_sub_append(tree, tok822_alloc('@', (char *) 0));
+           tok822_sub_append(tree, tok822_scan(var_myhostname, (TOK822 **) 0));
+           continue;
+       }
 
        /*
         * We're done. There are no domains left to strip off the address,
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/util/exec_command.c
--- a/external/ibm-public/postfix/dist/src/util/exec_command.c  Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/util/exec_command.c  Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: exec_command.c,v 1.1.1.1 2009/06/23 10:08:59 tron Exp $        */
+/*     $NetBSD: exec_command.c,v 1.1.1.1.12.1 2013/09/07 16:28:35 bouyer Exp $ */
 
 /*++
 /* NAME
@@ -65,7 +65,8 @@
     /*
      * See if this command contains any shell magic characters.
      */
-    if (command[strspn(command, ok_chars)] == 0) {
+    if (command[strspn(command, ok_chars)] == 0
+       && command[strspn(command, SPACE_TAB)] != 0) {
 
        /*
         * No shell meta characters found, so we can try to avoid the overhead



Home | Main Index | Thread Index | Old Index
diff -r 7876c7f7afd4 -r a4ceb121e0a6 external/ibm-public/postfix/dist/src/smtp/smtp_connect.c
--- a/external/ibm-public/postfix/dist/src/smtp/smtp_connect.c  Sat Sep 07 16:23:24 2013 +0000
+++ b/external/ibm-public/postfix/dist/src/smtp/smtp_connect.c  Sat Sep 07 16:28:34 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: smtp_connect.c,v 1.1.1.2 2010/06/17 18:07:02 tron Exp $        */
+/*     $NetBSD: smtp_connect.c,v 1.1.1.2.8.1 2013/09/07 16:28:34 bouyer Exp $  */
 
 /*++
 /* NAME
@@ -458,12 +458,12 @@
     state->misc_flags &= ~SMTP_MISC_FLAG_CONN_CACHE_MASK;
 
     /*
      * XXX Disable connection caching when sender-dependent authentication is
      * enabled. We must not send someone elses mail over an authenticated
      * connection, and we must not send mail that requires authentication
      * over a connection that wasn't authenticated.
      */
-    if (var_smtp_sender_auth)
+    if (var_smtp_sasl_passwd && *var_smtp_sasl_passwd)
        return;
 
     if (smtp_cache_dest && string_list_match(smtp_cache_dest, dest)) {
@@ -458,12 +458,12 @@
 
     /*
-     * XXX Disable connection caching when sender-dependent authentication is
+     * XXX Disable connection caching when SASL authentication is
      * enabled. We must not send someone elses mail over an authenticated
      * connection, and we must not send mail that requires authentication